@@ -162,7 +162,7 @@ class SecCompany:
         }
 
         # Safely build Ticker-to-Class mapping
-        share_class_dict = {'us-gaap:CommonStockMember':company_info['tickers'][0].text.strip()} if len(company_info['tickers']) == 1 else {"N/A":"N/A"}
+        share_class_dict = {'us-gaap:CommonStockMember':company_info['tickers'][0].text.strip()} if len(company_info['tickers']) == 1 else {"N/A":None}
         for elem in company_info["tickers"]:
             context_ref = elem.attrib.get("contextRef")
             if not context_ref:
@@ -173,14 +173,14 @@ class SecCompany:
             explicit = context.find('.//xbrldi:explicitMember[@dimension="us-gaap:StatementClassOfStockAxis"]',
                                     namespaces=namespaces)
             if explicit is not None and explicit.text:
-                share_class_dict[explicit.text.strip()] = elem.text.strip() if elem.text else "N/A"
+                share_class_dict[explicit.text.strip()] = elem.text.strip() if elem.text else None
 
         # Flatten values in company_info
         for key in company_info:
             company_info[key] = [elem.text for elem in company_info[key] if elem.text]
 
-        company_info["name"] = company_info["name"][0] if company_info["name"] else "N/A"
-        company_info["cik"] = company_info["cik"][0] if company_info["cik"] else "N/A"
+        company_info["name"] = company_info["name"][0] if company_info["name"] else None
+        company_info["cik"] = company_info["cik"][0] if company_info["cik"] else None
         company_info["url"] = self.url
 
 
@@ -199,13 +199,13 @@ class SecCompany:
                                             namespaces=namespaces) if context is not None else None
 
                     class_tag = explicit_member.text.strip() if explicit_member is not None and explicit_member.text else "us-gaap:CommonStockMember"
-                    date_val = date_elem.text if date_elem is not None and date_elem.text else "N/A"
-                    ticker_val = share_class_dict.get(class_tag, "N/A")
-                    value = elem.text if elem.text else "N/A"
+                    date_val = date_elem.text if date_elem is not None and date_elem.text else None
+                    ticker_val = share_class_dict.get(class_tag, None)
+                    value = elem.text if elem.text else None
 
                     data_list.append([ticker_val, value, date_val, class_tag])
                 except Exception as e:
-                    data_list.append(["N/A", elem.text if elem.text else "N/A", "N/A", "N/A"])
+                    data_list.append([None, elem.text if elem.text else None, None, None])
             attribute_roots[tag] = data_list
 
         # Build return dict or DataFrame
@@ -217,23 +217,31 @@ class SecCompany:
         if self.return_type == "df":
             rows = []
             for tag, records in result["data"].items():
-                for row in records:
+                if not records:
                     rows.append([
                         company_info["url"],
                         company_info["name"],
                         company_info["cik"],
                         company_info["tickers"],
                         tag,
-                        row[0],  # val associated ticker
-                        row[1],  # value
-                        row[2],  # date
-                        row[3]   # class type
+                        pd.NA,pd.NA,pd.NA,pd.NA
                     ])
+                else:
+                    for row in records:
+                        rows.append([
+                            company_info["url"],
+                            company_info["name"],
+                            company_info["cik"],
+                            company_info["tickers"],
+                            tag,
+                            row[0], row[1], row[2], row[3]
+                        ])
             result = pd.DataFrame(rows, columns=[
                 "url", "name", "cik", "public_tickers", "data_tag",
                 "val_associated_ticker", "val", "date", "class_type"
             ])
 
+
         return result
 
     def xml_parser(self,attributes:list):
@@ -262,14 +270,17 @@ def get_tickers(email):
     return df
 
 
-def get_close_price(headers,ticker):
-    headers = {
-    'Content-Type': 'application/json',
-    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36',
-    'Origin': 'https://www.nasdaq.com',
-    'Referer': 'https://www.nasdaq.com/'
-    }
-    url = f"https://api.nasdaq.com/api/quote/{ticker}/summary?assetclass=stocks"
-    req = requests.get(url, headers=headers)
-    price = float(req.json()["data"]["summaryData"]["PreviousClose"]["value"].replace("$","").replace(",",""))
+def get_close_price(ticker):
+    try:
+        headers = {
+        'Content-Type': 'application/json',
+        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36',
+        'Origin': 'https://www.nasdaq.com',
+        'Referer': 'https://www.nasdaq.com/'
+        }
+        url = f"https://api.nasdaq.com/api/quote/{ticker}/summary?assetclass=stocks"
+        req = requests.get(url, headers=headers)
+        price = float(req.json()["data"]["summaryData"]["PreviousClose"]["value"].replace("$","").replace(",",""))
+    except:
+        price = None
     return [ticker,price]
\ No newline at end of file
